import { defineConfig } from "astro/config";
import tailwind from "@astrojs/tailwind";
import mdx from "@astrojs/mdx";
import sitemap from "@astrojs/sitemap";
import node from "@astrojs/node";
import rehypePrettyCode from "rehype-pretty-code";
import rehypeSlug from "rehype-slug";
import react from "@astrojs/react";

// https://astro.build/config
export default defineConfig({
  output: "hybrid",
  adapter: node({
    mode: "standalone",
  }),
  site: "https://cyrilsebek.cz",
  integrations: [
    tailwind({
      applyBaseStyles: false,
    }),
    mdx({
      syntaxHighlight: false,
      rehypePlugins: [rehypeSlug, [rehypePrettyCode, { theme: "github-dark" }]],
    }),
    sitemap({
      i18n: {
        defaultLocale: "en",
        locales: {
          en: "en-US",
          de: "de-DE",
          cs: "cs-CZ",
          fr: "fr-FR"
        }
      }
    }),
    react(),
  ],
  i18n: {
    locales: [
      {
        path: "cs",
        codes: ["cs", "sk"],
      },
      {
        path: "de",
        codes: ["de", "gsw"],
      },
      {
        path: "en",
        codes: ["en"],
      },
      {
        path: "fr",
        codes: ["fr"],
      },
    ],
    defaultLocale: "en",
    routing: {
      redirectToDefaultLocale: false,
      prefixDefaultLocale: true
    },
    fallback: {
      de: "en",
      fr: "en",
    },
  },
});
